# Acknowledgements

## Citation

If you end up using any of the code or ideas you find here in your academic research, please cite our paper: [A. I. Malz et al 2018 AJ 156 35](https://ui.adsabs.harvard.edu/abs/2018AJ....156...35M/abstract) ([ADS - BibTex](https://ui.adsabs.harvard.edu/abs/2018AJ....156...35M/exportcitation)).

## Contributors

For an up-to-date dynamic list of contributors go to the [github contributors page](https://github.com/LSSTDESC/qp/graphs/contributors).

- Alex Malz
- Phil Marshall
- Eric Charles
- Sam Schmidt
- Jennifer Scora
- Mubdi Rahman
